==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/NotaOdplatnoscPozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusPozycjiNotyOdplatnosc;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class NotaOdplatnoscPozycja extends GenericDPSObject {
    /**
     * NOTA_ODPLATNOSC_POZYCJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long notaId;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwota;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kontoId;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.STATUS
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private StatusPozycjiNotyOdplatnosc status;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private BigDecimal kwotaOdpisu;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getNotaId() {
        return notaId;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     *
     * @param notaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setNotaId(Long notaId) {
        this.notaId = notaId;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KWOTA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKontoId() {
        return kontoId;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.STATUS
     * @mbggenerated 2014-03-10 10:45:37
     */
    public StatusPozycjiNotyOdplatnosc getStatus() {
        return status;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setStatus(StatusPozycjiNotyOdplatnosc status) {
        this.status = status;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public BigDecimal getKwotaOdpisu() {
        return kwotaOdpisu;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     *
     * @param kwotaOdpisu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwotaOdpisu(BigDecimal kwotaOdpisu) {
        this.kwotaOdpisu = kwotaOdpisu;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NotaOdplatnoscPozycja other = (NotaOdplatnoscPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNotaId() == null ? other.getNotaId() == null : this.getNotaId().equals(other.getNotaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getKwotaOdpisu() == null ? other.getKwotaOdpisu() == null : this.getKwotaOdpisu().equals(other.getKwotaOdpisu()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNotaId() == null) ? 0 : getNotaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getKwotaOdpisu() == null) ? 0 : getKwotaOdpisu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", notaId=").append(notaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", kontoId=").append(kontoId);
        sb.append(", status=").append(status);
        sb.append(", kwotaOdpisu=").append(kwotaOdpisu);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/NotaOdplatnoscPozycja.java <==
package pl.topteam.dps.model.main_gen;

import java.math.BigDecimal;
import pl.topteam.dps.enums.StatusPozycjiNotyOdplatnosc;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class NotaOdplatnoscPozycja extends GenericDPSObject {
    /**
     * NOTA_ODPLATNOSC_POZYCJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long notaId;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwota;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kontoId;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.STATUS
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private StatusPozycjiNotyOdplatnosc status;

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private BigDecimal kwotaOdpisu;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getNotaId() {
        return notaId;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.NOTA_ID
     *
     * @param notaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setNotaId(Long notaId) {
        this.notaId = notaId;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KWOTA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwota() {
        return kwota;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA
     *
     * @param kwota
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwota(BigDecimal kwota) {
        this.kwota = kwota;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKontoId() {
        return kontoId;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KONTO_ID
     *
     * @param kontoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKontoId(Long kontoId) {
        this.kontoId = kontoId;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.STATUS
     * @mbggenerated 2014-03-13 16:02:38
     */
    public StatusPozycjiNotyOdplatnosc getStatus() {
        return status;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.STATUS
     *
     * @param status
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setStatus(StatusPozycjiNotyOdplatnosc status) {
        this.status = status;
    }

    /**
     * @return NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public BigDecimal getKwotaOdpisu() {
        return kwotaOdpisu;
    }

    /**
     * NOTA_ODPLATNOSC_POZYCJA.KWOTA_ODPISU
     *
     * @param kwotaOdpisu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwotaOdpisu(BigDecimal kwotaOdpisu) {
        this.kwotaOdpisu = kwotaOdpisu;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NotaOdplatnoscPozycja other = (NotaOdplatnoscPozycja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getNotaId() == null ? other.getNotaId() == null : this.getNotaId().equals(other.getNotaId()))
            && (this.getKwota() == null ? other.getKwota() == null : this.getKwota().equals(other.getKwota()))
            && (this.getKontoId() == null ? other.getKontoId() == null : this.getKontoId().equals(other.getKontoId()))
            && (this.getStatus() == null ? other.getStatus() == null : this.getStatus().equals(other.getStatus()))
            && (this.getKwotaOdpisu() == null ? other.getKwotaOdpisu() == null : this.getKwotaOdpisu().equals(other.getKwotaOdpisu()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getNotaId() == null) ? 0 : getNotaId().hashCode());
        result = prime * result + ((getKwota() == null) ? 0 : getKwota().hashCode());
        result = prime * result + ((getKontoId() == null) ? 0 : getKontoId().hashCode());
        result = prime * result + ((getStatus() == null) ? 0 : getStatus().hashCode());
        result = prime * result + ((getKwotaOdpisu() == null) ? 0 : getKwotaOdpisu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", notaId=").append(notaId);
        sb.append(", kwota=").append(kwota);
        sb.append(", kontoId=").append(kontoId);
        sb.append(", status=").append(status);
        sb.append(", kwotaOdpisu=").append(kwotaOdpisu);
        sb.append("]");
        return sb.toString();
    }
}
